@@ -1,12 +1,17 @@
 "Test helper functions and base test cases."
+from __future__ import unicode_literals
 
 import random
 import string
-import StringIO
 
 from django.core.cache import cache
 from django.core.management import call_command
 from django.test import TestCase
+try:
+    from django.utils.six import StringIO
+except ImportError:
+    # Django < 1.5. No Python 3 support
+    from StringIO import StringIO
 
 from adcode.models import Section, Size, Placement
 
@@ -18,7 +23,7 @@ class AdCodeDataTestCase(TestCase):
         cache.clear()
 
     def get_random_string(self, length=10):
-        return u''.join(random.choice(string.ascii_letters) for x in xrange(length))
+        return ''.join(random.choice(string.ascii_letters) for x in range(length))
 
     def create_section(self, **kwargs):
         "Factory method for creating Sections."
@@ -58,7 +63,7 @@ class FixturesTestCase(TestCase):
 
     def test_iab_sizes(self):
         "Load IAB size fixture."
-        out = StringIO.StringIO()
-        err = StringIO.StringIO()
+        out = StringIO()
+        err = StringIO()
         call_command('loaddata', 'iab_sizes.json', stdout=out, stderr=err)
         self.assertEqual(Size.objects.all().count(), 27)
